@@ -1,7 +1,7 @@
 /* slideshow.c
 
 Copyright (C) 1999-2003 Tom Gilbert.
-Copyright (C) 2010-2020 Daniel Friesel.
+Copyright (C) 2010-2020 Birte Kristina Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -165,7 +165,7 @@ void cb_reload_timer(void *data)
 		if (opt.filelistfile) {
 			filelist = gib_list_cat(filelist, feh_read_filelist(opt.filelistfile));
 		}
-		
+
 		if (!(filelist_len = gib_list_length(filelist))) {
 			eprintf("No files found to reload.");
 		}
@@ -385,7 +385,8 @@ void feh_action_run(feh_file * file, char *action, winwidget winwid)
 
 		if (opt.verbose && !opt.list && !opt.customlist)
 			fprintf(stderr, "Running action -->%s<--\n", sys);
-		system(sys);
+		if (system(sys) == -1)
+			perror("running action via system() failed");
 	}
 	return;
 }
@@ -528,6 +529,12 @@ char *feh_printf(char *str, feh_file * file, winwidget winwid)
 					strncat(ret, buf, sizeof(ret) - strlen(ret) - 1);
 				}
 				break;
+			case 'W':
+				if (winwid) {
+					snprintf(buf, sizeof(buf), "%dx%d+%d+%d", winwid->w, winwid->h, winwid->x, winwid->y);
+					strncat(ret, buf, sizeof(ret) - strlen(ret) - 1);
+				}
+				break;
 			case 'z':
 				if (winwid) {
 					snprintf(buf, sizeof(buf), "%.2f", winwid->zoom);
